@@ -51,10 +51,10 @@ class Auth(MiddlewareMixin):
             jwt_test = str(request.COOKIES.get('test'))
             if jwt_test == '1':
                 logger.info('test=1,use jwt user:' + str(jwt_user.username))
-                request.user = jwt_user
+                request._user = jwt_user
             else:
                 if not isinstance(jwt_user, AnonymousUser):
-                    request.user = jwt_user
+                    request._user = jwt_user
 
     def get_jwt_user(self, request):
         token = request.META.get("HTTP_JWTAUTHORIZATION")
